==> speechanalytic-billing_0.1.4_database.tar.gz: database/mssql/procedures/GetPlatformCancelledBatches.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTA FUNCION RETORNA LAS TARIFAS SETTEADAS DE UNA CUENTA O SUBCUENTA
CREATE PROCEDURE [dbo].[GetPlatformCancelledBatches] (
	@PlatformHash VARCHAR(100) = NULL,
	@InstallationId VARCHAR(100) = NULL
	)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- ESTADOS DE LOS BATCHASUMMARY:
	-- CREATED: ESTADO POR DEFECTO AL CREAR EL BATCH
	-- RUNNING: ESTADO CUANDO EL BATCH TIENE 1 O MAS DETALLES (BATCHDETAILED)
	-- PAUSED_BY_USER: ESTADO CUANDO EL BATCH ES PAUSADO POR EL USUARIO POR ALGUN MOTIVO
	-- PAUSED_BY_INSUFFICIENT_BALANCE: ESTADO CUANDO EL BATCH ES PAUSADO POR EL SISTEMA POR NO TENER SALDO DISPONIBLE
	-- CLOSED: ESTADO CUANDO EL BATCH TERMINO SIN PROBLEMA NI INTERVENSION
	-- CANCELLED_BY_TIMEOUT: ESTADO CUANDO EL BATCH ES TERMINADO POR EL SISTEMA POR SUPERAR 72 HORAS DESDE LA PAUSA
	-- CANCELLED_BY_USER: ESTADO CUANDO EL BATCH ES TERMINADO POR EL USUARIO POR ALGUN MOTIVO
	
	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- SCRIPT PARA RECUPERAR LOS BATCH ABIERTOS, QUE HAN SIDO CANCELADOS
		SELECT ASAVST.[InstallationId],
				ASAVST.[BatchId],
				ASAVST.[CreatedDate],
				ASAVST.[BatchTypeName],
				ASAVST.[BatchTypeId],
				ASAVST.[VCC],
				ASAVST.[SystemService],
				ASAVST.[Status]
			FROM [dbo].[AccountSubAccountVCCSummaryTransaction] ASAVST (NOLOCK)
			WHERE ASAVST.[InstallationId] = @InstallationId
				--AND ASAVST.[IsFinished] = 0
				--AND ASAVDT.[IsValid] = 1
				--AND ASAVDT.[IsFinished]= 1
				AND ASAVST.[Status] LIKE 'CANCELLED%'

    END TRY
    BEGIN CATCH
        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speechanalytic-billing_1.0.1_database.tar.gz: database/mssql/procedures/GetPlatformCancelledBatches.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTA FUNCION RETORNA LAS TARIFAS SETTEADAS DE UNA CUENTA O SUBCUENTA
CREATE PROCEDURE [dbo].[GetPlatformCancelledBatches] (
	@PlatformHash VARCHAR(100) = NULL,
	@InstallationId VARCHAR(100) = NULL
	)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- ESTADOS DE LOS BATCHASUMMARY:
	-- CREATED: ESTADO POR DEFECTO AL CREAR EL BATCH
	-- RUNNING: ESTADO CUANDO EL BATCH TIENE 1 O MAS DETALLES (BATCHDETAILED)
	-- PAUSED_BY_USER: ESTADO CUANDO EL BATCH ES PAUSADO POR EL USUARIO POR ALGUN MOTIVO
	-- PAUSED_BY_INSUFFICIENT_BALANCE: ESTADO CUANDO EL BATCH ES PAUSADO POR EL SISTEMA POR NO TENER SALDO DISPONIBLE
	-- CLOSED: ESTADO CUANDO EL BATCH TERMINO SIN PROBLEMA NI INTERVENSION
	-- CANCELLED_BY_PAUSED_TIMEOUT: ESTADO CUANDO EL BATCH ES TERMINADO POR EL SISTEMA POR SUPERAR 72 HORAS DESDE LA PAUSA
	-- CANCELLED_BY_RUNNING_TIMEOUT: ESTADO CUANDO EL BATCH ES TERMINADO POR EL SISTEMA POR SUPERAR 120 HORAS DESDE LA PAUSA
	-- CANCELLED_BY_USER: ESTADO CUANDO EL BATCH ES TERMINADO POR EL USUARIO POR ALGUN MOTIVO
	-- FINISHED_BY_CANCELLED_BY_PAUSED_TIMEOUT
	-- FINISHED_BY_CANCELLED_BY_RUNNING_TIMEOUT
	-- FINISHED_BY_CANCELLED_BY_USER 
	
	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- SCRIPT PARA RECUPERAR LOS BATCH ABIERTOS, QUE HAN SIDO CANCELADOS
		SELECT ASAVST.[InstallationId],
				ASAVST.[BatchId],
				ASAVST.[CreatedDate],
				ASAVST.[BatchTypeName],
				ASAVST.[BatchTypeId],
				ASAVST.[VCC],
				ASAVST.[SystemService],
				ASAVST.[Status]
			FROM [dbo].[AccountSubAccountVCCSummaryTransaction] ASAVST (NOLOCK)
			WHERE ASAVST.[InstallationId] = @InstallationId
				--AND ASAVST.[IsFinished] = 0
				--AND ASAVDT.[IsValid] = 1
				--AND ASAVDT.[IsFinished]= 1
				AND ASAVST.[Status] LIKE 'CANCELLED%'

    END TRY
    BEGIN CATCH
        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
